@@ -3,6 +3,7 @@ use warnings;
 
 package TestClass;
 
+use Moose;
 use MooseX::Method::Signatures;
 
 method new ($class: Str $foo, Int $bar = 42
@@ -34,4 +35,6 @@ method combined ($a, $b, $c?, :$optional, :$required!) {
     return ($a, $b, $c, $optional, $required);
 }
 
+no Moose;
+
 1;
